==> apache-pulsar-client-cpp-3.1.1.tar.gz: apache-pulsar-client-cpp-3.1.1/tests/WaitUtils.h <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
#pragma once

#include <chrono>
#include <functional>
#include <thread>

namespace pulsar {

template <typename Rep, typename Period>
inline void waitUntil(std::chrono::duration<Rep, Period> timeout, const std::function<bool()>& condition,
                      long durationMs = 10) {
    auto timeoutMs = std::chrono::duration_cast<std::chrono::milliseconds>(timeout).count();
    while (timeoutMs > 0) {
        auto now = std::chrono::high_resolution_clock::now();
        if (condition()) {
            break;
        }
        std::this_thread::sleep_for(std::chrono::milliseconds(durationMs));
        auto elapsed = std::chrono::duration_cast<std::chrono::milliseconds>(
                           std::chrono::high_resolution_clock::now() - now)
                           .count();
        timeoutMs -= elapsed;
    }
}

}  // namespace pulsar

==> apache-pulsar-client-cpp-4.0.0.tar.gz: apache-pulsar-client-cpp-4.0.0/tests/WaitUtils.h <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
#pragma once

#include <chrono>
#include <functional>
#include <thread>

namespace pulsar {

template <typename Rep, typename Period>
inline bool waitUntil(std::chrono::duration<Rep, Period> timeout, const std::function<bool()>& condition,
                      long durationMs = 10) {
    auto timeoutMs = std::chrono::duration_cast<std::chrono::milliseconds>(timeout).count();
    while (timeoutMs > 0) {
        auto now = std::chrono::high_resolution_clock::now();
        if (condition()) {
            return true;
        }
        std::this_thread::sleep_for(std::chrono::milliseconds(durationMs));
        auto elapsed = std::chrono::duration_cast<std::chrono::milliseconds>(
                           std::chrono::high_resolution_clock::now() - now)
                           .count();
        timeoutMs -= elapsed;
    }
    return false;
}

}  // namespace pulsar
